# coding=utf-8

from django.db import transaction
from rest_framework.views import APIView
from utils.permission import IsAdministrator
from utils import response_error, response_ok
from utils.custom_modelviewset import CustomModelViewSet
from apps.system.models import SysLog

from apps.examination.exam.models import Exam
from apps.examination.exam.filters import ExamFilter
from apps.examination.exam.serializers import ExamSerializer

class ExamViewSet(CustomModelViewSet):
    permission_classes = [IsAdministrator, ]
    queryset = Exam.objects.filter(delete=False)
    serializer_class = ExamSerializer

    def filter_queryset(self, queryset):
        f = ExamFilter(self.request.GET, queryset=queryset)
        return f.qs

    def perform_create(self, serializer):
        super(ExamViewSet, self).perform_create(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        SysLog.objects.addnew(self.request.user, SysLog.INSERT, u'添加考试[%s]，id=%d' % (instance.name, instance.id), validated_data)

    def perform_update(self, serializer):
        super(ExamViewSet, self).perform_update(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        SysLog.objects.addnew(self.request.user, SysLog.UPDATE, u'修改考试[%s]，id=%d' % (instance.name, instance.id), validated_data)

    def destroy(self, request, *args, **kwargs):
        with transaction.atomic():
            instance = self.get_object()
            instance.delete = True
            instance.save()
            SysLog.objects.addnew(self.request.user, SysLog.DELETE, u'删除考试[%s]，id=%d' % (instance.name, instance.id))
        return response_ok()